@@ -10,6 +10,9 @@ class Config(object):
             regex = re.compile('(https?:\/\/)(.*):(.*)@(.*)\/orgs\/([a-z0-9]*)\/projects\/([a-z0-9]*)\/envs\/([a-z0-9]*)\/config', re.I)
             matches = regex.match(url)
 
+            if matches is None:
+                raise Exception('Invalid url')
+
             url = {
                 'host': matches.group(1) + matches.group(4), 'user': matches.group(2), 'pass': matches.group(3),
                 'org': matches.group(5), 'project': matches.group(6), 'env': matches.group(7)
